from meshtrade.type.v1 import ledger_pb2 as _ledger_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Token(_message.Message):
    __slots__ = ("code", "issuer", "ledger")
    CODE_FIELD_NUMBER: _ClassVar[int]
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    LEDGER_FIELD_NUMBER: _ClassVar[int]
    code: str
    issuer: str
    ledger: _ledger_pb2.Ledger
    def __init__(self, code: _Optional[str] = ..., issuer: _Optional[str] = ..., ledger: _Optional[_Union[_ledger_pb2.Ledger, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/ledger/transaction/v1/transaction_action.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/ledger/transaction/v1/transaction_action.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8meshtrade/ledger/transaction/v1/transaction_action.proto\x12\x1fmeshtrade.ledger.transaction.v1*\xf8\x01\n\x11TransactionAction\x12\"\n\x1eTRANSACTION_ACTION_UNSPECIFIED\x10\x00\x12!\n\x1dTRANSACTION_ACTION_DO_NOTHING\x10\x01\x12\x1c\n\x18TRANSACTION_ACTION_BUILD\x10\x02\x12\x1d\n\x19TRANSACTION_ACTION_COMMIT\x10\x03\x12\x1b\n\x17TRANSACTION_ACTION_SIGN\x10\x04\x12#\n\x1fTRANSACTION_ACTION_MARK_PENDING\x10\x05\x12\x1d\n\x19TRANSACTION_ACTION_SUBMIT\x10\x06\x42\x41Z?github.com/meshtrade/api/go/ledger/transaction/v1;transactionv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.ledger.transaction.v1.transaction_action_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z?github.com/meshtrade/api/go/ledger/transaction/v1;transactionv1'
  _globals['_TRANSACTIONACTION']._serialized_start=94
  _globals['_TRANSACTIONACTION']._serialized_end=342
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/group/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/group/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.iam.group.v1 import group_pb2 as meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$meshtrade/iam/group/v1/service.proto\x12\x16meshtrade.iam.group.v1\x1a\"meshtrade/iam/group/v1/group.proto\"\x11\n\x0fGetGroupRequest2b\n\x0cGroupService\x12R\n\x08GetGroup\x12\'.meshtrade.iam.group.v1.GetGroupRequest\x1a\x1d.meshtrade.iam.group.v1.GroupB2Z0github.com/meshtrade/api/go/iam/group/v1;groupv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.group.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/meshtrade/api/go/iam/group/v1;groupv1'
  _globals['_GETGROUPREQUEST']._serialized_start=100
  _globals['_GETGROUPREQUEST']._serialized_end=117
  _globals['_GROUPSERVICE']._serialized_start=119
  _globals['_GROUPSERVICE']._serialized_end=217
# @@protoc_insertion_point(module_scope)



from google.type import date_pb2 as _date_pb2
from meshtrade.compliance.client.v1 import company_representative_pb2 as _company_representative_pb2
from meshtrade.compliance.client.v1 import fund_pb2 as _fund_pb2
from meshtrade.compliance.client.v1 import industry_classification_pb2 as _industry_classification_pb2
from meshtrade.compliance.client.v1 import natural_person_pb2 as _natural_person_pb2
from meshtrade.compliance.client.v1 import trust_pb2 as _trust_pb2
from meshtrade.type.v1 import address_pb2 as _address_pb2
from meshtrade.type.v1 import decimal_pb2 as _decimal_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LegalPersonConnectionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    LEGAL_PERSON_CONNECTION_TYPE_UNSPECIFIED: _ClassVar[LegalPersonConnectionType]
    LEGAL_PERSON_CONNECTION_TYPE_SHAREHOLDER: _ClassVar[LegalPersonConnectionType]
    LEGAL_PERSON_CONNECTION_TYPE_PARENT_COMPANY: _ClassVar[LegalPersonConnectionType]
    LEGAL_PERSON_CONNECTION_TYPE_CORPORATE_DIRECTOR: _ClassVar[LegalPersonConnectionType]
    LEGAL_PERSON_CONNECTION_TYPE_TRUST: _ClassVar[LegalPersonConnectionType]
    LEGAL_PERSON_CONNECTION_TYPE_GENERAL_PARTNER: _ClassVar[LegalPersonConnectionType]
    LEGAL_PERSON_CONNECTION_TYPE_GUARANTOR: _ClassVar[LegalPersonConnectionType]
LEGAL_PERSON_CONNECTION_TYPE_UNSPECIFIED: LegalPersonConnectionType
LEGAL_PERSON_CONNECTION_TYPE_SHAREHOLDER: LegalPersonConnectionType
LEGAL_PERSON_CONNECTION_TYPE_PARENT_COMPANY: LegalPersonConnectionType
LEGAL_PERSON_CONNECTION_TYPE_CORPORATE_DIRECTOR: LegalPersonConnectionType
LEGAL_PERSON_CONNECTION_TYPE_TRUST: LegalPersonConnectionType
LEGAL_PERSON_CONNECTION_TYPE_GENERAL_PARTNER: LegalPersonConnectionType
LEGAL_PERSON_CONNECTION_TYPE_GUARANTOR: LegalPersonConnectionType

class Company(_message.Message):
    __slots__ = ("registered_name", "registration_number", "tax_identifier", "country_of_incorporation", "date_of_incorporation", "registered_address", "principal_physical_address", "postal_address", "head_office_address", "company_representatives", "connected_legal_persons", "industry_classification", "listed_exchange_code", "listing_reference")
    REGISTERED_NAME_FIELD_NUMBER: _ClassVar[int]
    REGISTRATION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    TAX_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_OF_INCORPORATION_FIELD_NUMBER: _ClassVar[int]
    DATE_OF_INCORPORATION_FIELD_NUMBER: _ClassVar[int]
    REGISTERED_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PRINCIPAL_PHYSICAL_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    POSTAL_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    HEAD_OFFICE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COMPANY_REPRESENTATIVES_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_LEGAL_PERSONS_FIELD_NUMBER: _ClassVar[int]
    INDUSTRY_CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    LISTED_EXCHANGE_CODE_FIELD_NUMBER: _ClassVar[int]
    LISTING_REFERENCE_FIELD_NUMBER: _ClassVar[int]
    registered_name: str
    registration_number: str
    tax_identifier: str
    country_of_incorporation: str
    date_of_incorporation: _date_pb2.Date
    registered_address: _address_pb2.Address
    principal_physical_address: _address_pb2.Address
    postal_address: _address_pb2.Address
    head_office_address: _address_pb2.Address
    company_representatives: _containers.RepeatedCompositeFieldContainer[_company_representative_pb2.CompanyRepresentative]
    connected_legal_persons: _containers.RepeatedCompositeFieldContainer[ConnectedLegalPerson]
    industry_classification: _industry_classification_pb2.IndustryClassification
    listed_exchange_code: str
    listing_reference: str
    def __init__(self, registered_name: _Optional[str] = ..., registration_number: _Optional[str] = ..., tax_identifier: _Optional[str] = ..., country_of_incorporation: _Optional[str] = ..., date_of_incorporation: _Optional[_Union[_date_pb2.Date, _Mapping]] = ..., registered_address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., principal_physical_address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., postal_address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., head_office_address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., company_representatives: _Optional[_Iterable[_Union[_company_representative_pb2.CompanyRepresentative, _Mapping]]] = ..., connected_legal_persons: _Optional[_Iterable[_Union[ConnectedLegalPerson, _Mapping]]] = ..., industry_classification: _Optional[_Union[_industry_classification_pb2.IndustryClassification, _Mapping]] = ..., listed_exchange_code: _Optional[str] = ..., listing_reference: _Optional[str] = ...) -> None: ...

class ConnectedLegalPerson(_message.Message):
    __slots__ = ("natural_person", "company", "fund", "trust", "connection_types", "ownership_percentage", "voting_rights_percentage", "connection_description")
    NATURAL_PERSON_FIELD_NUMBER: _ClassVar[int]
    COMPANY_FIELD_NUMBER: _ClassVar[int]
    FUND_FIELD_NUMBER: _ClassVar[int]
    TRUST_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_TYPES_FIELD_NUMBER: _ClassVar[int]
    OWNERSHIP_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    VOTING_RIGHTS_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    natural_person: _natural_person_pb2.NaturalPerson
    company: Company
    fund: _fund_pb2.Fund
    trust: _trust_pb2.Trust
    connection_types: _containers.RepeatedScalarFieldContainer[LegalPersonConnectionType]
    ownership_percentage: _decimal_pb2.Decimal
    voting_rights_percentage: _decimal_pb2.Decimal
    connection_description: str
    def __init__(self, natural_person: _Optional[_Union[_natural_person_pb2.NaturalPerson, _Mapping]] = ..., company: _Optional[_Union[Company, _Mapping]] = ..., fund: _Optional[_Union[_fund_pb2.Fund, _Mapping]] = ..., trust: _Optional[_Union[_trust_pb2.Trust, _Mapping]] = ..., connection_types: _Optional[_Iterable[_Union[LegalPersonConnectionType, str]]] = ..., ownership_percentage: _Optional[_Union[_decimal_pb2.Decimal, _Mapping]] = ..., voting_rights_percentage: _Optional[_Union[_decimal_pb2.Decimal, _Mapping]] = ..., connection_description: _Optional[str] = ...) -> None: ...



"""
This module provides a factory function for creating Amount protobuf messages.
"""

from decimal import ROUND_DOWN, Decimal

from .amount_pb2 import Amount
from .decimal_built_in_conversions import built_in_to_decimal, decimal_to_built_in
from .ledger import get_ledger_no_decimal_places
from .token_pb2 import Token


def new_amount(
    value: Decimal,
    token: Token,
    precision_loss_tolerance: Decimal = Decimal("0.00000001")
) -> Amount:
    """Creates a new Amount, ensuring the value conforms to system-wide limits.

    This function is the safe constructor for creating Amount protobuf messages.
    While the underlying conversion from a Python `Decimal` to the protobuf's
    `string` field is lossless, this function provides critical validation
    to ensure the value adheres to constraints imposed by other downstream
    systems (e.g., databases, other microservices with fixed-precision types).

    Its primary operations are:

    1.  **Validation:** It performs a serialization round-trip
        (Python Decimal -> Protobuf Decimal -> Python Decimal) to simulate
        how the value is stored and retrieved across the system. It then asserts
        the value remains unchanged, guaranteeing it doesn't exceed the
        precision limits of any consuming service.

    2.  **Truncation:** It truncates the validated value to the exact number of
        decimal places defined for the token's ledger, always rounding down to
        prevent any inflation of values.

    3.  **Construction:** It constructs and returns the final `Amount` message.

    Args:
        value: The numerical value of the amount as a Python `Decimal` object.
        token: The `Token` protobuf message that defines the asset type
               and its associated ledger.
        precision_loss_tolerance: The maximum acceptable difference after the
            validation round-trip. Since the string-based conversion is
            lossless, any difference indicates a failure to conform to an
            external system's parsing rules. Defaults to a small tolerance
            for robustness.

    Returns:
        An `Amount` protobuf message containing the ledger-compliant, truncated
        value and the specified token.

    Raises:
        AssertionError: If the input `value` changes during the validation
                        round-trip, indicating it exceeds the system's
                        representational limits and would be corrupted
                        downstream.
    """

    # Perform a serialization round-trip to validate the value against
    # system-wide architectural constraints. This is a lossless operation
    # in isolation, so any change reveals an incompatibility.
    value_after_roundtrip = decimal_to_built_in(built_in_to_decimal(value))

    # Confirm the value is perfectly representable within the system's limits.
    # If the original value had too much precision for a downstream service to
    # parse, it would change during the round-trip, and this would fail.
    assert abs(value_after_roundtrip - value) \
        <= precision_loss_tolerance, \
            "value exceeds system's precision limits and would be corrupted"

    # Truncate the validated value to the number of decimal places specified by the
    # token's ledger. ROUND_DOWN ensures the value is never inflated.
    truncated_value = value_after_roundtrip.quantize(
        Decimal(10) ** -get_ledger_no_decimal_places(token.ledger),
        rounding=ROUND_DOWN,
    )

    # Construct and return the final Amount protobuf message using the sanitized value.
    return Amount(
        token=token,
        value=built_in_to_decimal(truncated_value),
    )



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Role(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ROLE_UNSPECIFIED: _ClassVar[Role]
    ROLE_WALLET_ADMIN: _ClassVar[Role]
    ROLE_WALLET_VIEWER: _ClassVar[Role]
ROLE_UNSPECIFIED: Role
ROLE_WALLET_ADMIN: Role
ROLE_WALLET_VIEWER: Role
STANDARD_ROLES_FIELD_NUMBER: _ClassVar[int]
standard_roles: _descriptor.FieldDescriptor
ROLES_FIELD_NUMBER: _ClassVar[int]
roles: _descriptor.FieldDescriptor

class RoleList(_message.Message):
    __slots__ = ("roles",)
    ROLES_FIELD_NUMBER: _ClassVar[int]
    roles: _containers.RepeatedScalarFieldContainer[Role]
    def __init__(self, roles: _Optional[_Iterable[_Union[Role, str]]] = ...) -> None: ...



from google.type import date_pb2 as _date_pb2
from meshtrade.compliance.client.v1 import company_representative_role_pb2 as _company_representative_role_pb2
from meshtrade.compliance.client.v1 import natural_person_pb2 as _natural_person_pb2
from meshtrade.type.v1 import contact_details_pb2 as _contact_details_pb2
from meshtrade.type.v1 import decimal_pb2 as _decimal_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CompanyRepresentative(_message.Message):
    __slots__ = ("natural_person", "role", "position", "ownership_percentage", "professional_contact_details", "date_of_appointment")
    NATURAL_PERSON_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    OWNERSHIP_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    PROFESSIONAL_CONTACT_DETAILS_FIELD_NUMBER: _ClassVar[int]
    DATE_OF_APPOINTMENT_FIELD_NUMBER: _ClassVar[int]
    natural_person: _natural_person_pb2.NaturalPerson
    role: _company_representative_role_pb2.CompanyRepresentativeRole
    position: str
    ownership_percentage: _decimal_pb2.Decimal
    professional_contact_details: _contact_details_pb2.ContactDetails
    date_of_appointment: _date_pb2.Date
    def __init__(self, natural_person: _Optional[_Union[_natural_person_pb2.NaturalPerson, _Mapping]] = ..., role: _Optional[_Union[_company_representative_role_pb2.CompanyRepresentativeRole, str]] = ..., position: _Optional[str] = ..., ownership_percentage: _Optional[_Union[_decimal_pb2.Decimal, _Mapping]] = ..., professional_contact_details: _Optional[_Union[_contact_details_pb2.ContactDetails, _Mapping]] = ..., date_of_appointment: _Optional[_Union[_date_pb2.Date, _Mapping]] = ...) -> None: ...



from .amount import new_amount
from .decimal_built_in_conversions import built_in_to_decimal, decimal_to_built_in
from .decimal_pb2 import Decimal
from .ledger_pb2 import Ledger
from .ledger import get_ledger_no_decimal_places
from .token_pb2 import Token
from .amount_pb2 import Amount


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.compliance.client.v1 import client_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,meshtrade/compliance/client/v1/service.proto\x12\x1emeshtrade.compliance.client.v1\x1a+meshtrade/compliance/client/v1/client.proto\"&\n\x10GetClientRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"\x14\n\x12ListClientsRequest\"W\n\x13ListClientsResponse\x12@\n\x07\x63lients\x18\x01 \x03(\x0b\x32&.meshtrade.compliance.client.v1.ClientR\x07\x63lients2\xee\x01\n\rClientService\x12\x65\n\tGetClient\x12\x30.meshtrade.compliance.client.v1.GetClientRequest\x1a&.meshtrade.compliance.client.v1.Client\x12v\n\x0bListClients\x12\x32.meshtrade.compliance.client.v1.ListClientsRequest\x1a\x33.meshtrade.compliance.client.v1.ListClientsResponseB;Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1'
  _globals['_GETCLIENTREQUEST']._serialized_start=125
  _globals['_GETCLIENTREQUEST']._serialized_end=163
  _globals['_LISTCLIENTSREQUEST']._serialized_start=165
  _globals['_LISTCLIENTSREQUEST']._serialized_end=185
  _globals['_LISTCLIENTSRESPONSE']._serialized_start=187
  _globals['_LISTCLIENTSRESPONSE']._serialized_end=274
  _globals['_CLIENTSERVICE']._serialized_start=277
  _globals['_CLIENTSERVICE']._serialized_end=515
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/wallet/account/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/wallet/account/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.option.v1 import auth_pb2 as meshtrade_dot_option_dot_v1_dot_auth__pb2
from meshtrade.option.v1 import service_type_pb2 as meshtrade_dot_option_dot_v1_dot_service__type__pb2
from meshtrade.type.v1 import ledger_pb2 as meshtrade_dot_type_dot_v1_dot_ledger__pb2
from meshtrade.wallet.account.v1 import account_pb2 as meshtrade_dot_wallet_dot_account_dot_v1_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)meshtrade/wallet/account/v1/service.proto\x12\x1bmeshtrade.wallet.account.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1emeshtrade/option/v1/auth.proto\x1a&meshtrade/option/v1/service_type.proto\x1a\x1emeshtrade/type/v1/ledger.proto\x1a)meshtrade/wallet/account/v1/account.proto\"\x8b\x01\n\x14\x43reateAccountRequest\x12\"\n\x05label\x18\x01 \x01(\tB\x0c\xbaH\tr\x04\x10\x03\x18\x32\xc8\x01\x01R\x05label\x12;\n\x06ledger\x18\x02 \x01(\x0e\x32\x19.meshtrade.type.v1.LedgerB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x06ledger\x12\x12\n\x04open\x18\x03 \x01(\x08R\x04open\"8\n\x11GetAccountRequest\x12#\n\x06number\x18\x01 \x01(\tB\x0b\xbaH\x08r\x03\x98\x01\x07\xc8\x01\x01R\x06number\"\x15\n\x13ListAccountsRequest\"X\n\x14ListAccountsResponse\x12@\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32$.meshtrade.wallet.account.v1.AccountR\x08\x61\x63\x63ounts\";\n\x15SearchAccountsRequest\x12\"\n\x05label\x18\x01 \x01(\tB\x0c\xbaH\tr\x04\x10\x03\x18\x32\xc8\x01\x00R\x05label\"Z\n\x16SearchAccountsResponse\x12@\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32$.meshtrade.wallet.account.v1.AccountR\x08\x61\x63\x63ounts2\x87\x04\n\x0e\x41\x63\x63ountService\x12u\n\rCreateAccount\x12\x31.meshtrade.wallet.account.v1.CreateAccountRequest\x1a$.meshtrade.wallet.account.v1.Account\"\x0b\xa0\xb5\x18\x02\xaa\xb5\x18\x03\n\x01\x01\x12p\n\nGetAccount\x12..meshtrade.wallet.account.v1.GetAccountRequest\x1a$.meshtrade.wallet.account.v1.Account\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x01\x02\x12\x81\x01\n\x0cListAccounts\x12\x30.meshtrade.wallet.account.v1.ListAccountsRequest\x1a\x31.meshtrade.wallet.account.v1.ListAccountsResponse\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x01\x02\x12\x87\x01\n\x0eSearchAccounts\x12\x32.meshtrade.wallet.account.v1.SearchAccountsRequest\x1a\x33.meshtrade.wallet.account.v1.SearchAccountsResponse\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x01\x02\x42\x41Z7github.com/meshtrade/api/go/wallet/account/v1;accountv1\x9a\xb5\x18\x04\n\x02\x01\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.wallet.account.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/meshtrade/api/go/wallet/account/v1;accountv1\232\265\030\004\n\002\001\002'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['label']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['label']._serialized_options = b'\272H\tr\004\020\003\0302\310\001\001'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['ledger']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['ledger']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_GETACCOUNTREQUEST'].fields_by_name['number']._loaded_options = None
  _globals['_GETACCOUNTREQUEST'].fields_by_name['number']._serialized_options = b'\272H\010r\003\230\001\007\310\001\001'
  _globals['_SEARCHACCOUNTSREQUEST'].fields_by_name['label']._loaded_options = None
  _globals['_SEARCHACCOUNTSREQUEST'].fields_by_name['label']._serialized_options = b'\272H\tr\004\020\003\0302\310\001\000'
  _globals['_ACCOUNTSERVICE'].methods_by_name['CreateAccount']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['CreateAccount']._serialized_options = b'\240\265\030\002\252\265\030\003\n\001\001'
  _globals['_ACCOUNTSERVICE'].methods_by_name['GetAccount']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['GetAccount']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\001\002'
  _globals['_ACCOUNTSERVICE'].methods_by_name['ListAccounts']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['ListAccounts']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\001\002'
  _globals['_ACCOUNTSERVICE'].methods_by_name['SearchAccounts']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['SearchAccounts']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\001\002'
  _globals['_CREATEACCOUNTREQUEST']._serialized_start=251
  _globals['_CREATEACCOUNTREQUEST']._serialized_end=390
  _globals['_GETACCOUNTREQUEST']._serialized_start=392
  _globals['_GETACCOUNTREQUEST']._serialized_end=448
  _globals['_LISTACCOUNTSREQUEST']._serialized_start=450
  _globals['_LISTACCOUNTSREQUEST']._serialized_end=471
  _globals['_LISTACCOUNTSRESPONSE']._serialized_start=473
  _globals['_LISTACCOUNTSRESPONSE']._serialized_end=561
  _globals['_SEARCHACCOUNTSREQUEST']._serialized_start=563
  _globals['_SEARCHACCOUNTSREQUEST']._serialized_end=622
  _globals['_SEARCHACCOUNTSRESPONSE']._serialized_start=624
  _globals['_SEARCHACCOUNTSRESPONSE']._serialized_end=714
  _globals['_ACCOUNTSERVICE']._serialized_start=717
  _globals['_ACCOUNTSERVICE']._serialized_end=1236
# @@protoc_insertion_point(module_scope)



from meshtrade.issuance_hub.instrument.v1 import instrument_pb2 as _instrument_pb2
from meshtrade.type.v1 import amount_pb2 as _amount_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetInstrumentRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class MintInstrumentRequest(_message.Message):
    __slots__ = ("amount", "fee_account", "destination_account")
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    FEE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    amount: _amount_pb2.Amount
    fee_account: str
    destination_account: str
    def __init__(self, amount: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ..., fee_account: _Optional[str] = ..., destination_account: _Optional[str] = ...) -> None: ...

class MintInstrumentResponse(_message.Message):
    __slots__ = ("transaction_id",)
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    transaction_id: str
    def __init__(self, transaction_id: _Optional[str] = ...) -> None: ...

class BurnInstrumentRequest(_message.Message):
    __slots__ = ("amount", "fee_account", "source_account")
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    FEE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    SOURCE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    amount: _amount_pb2.Amount
    fee_account: str
    source_account: str
    def __init__(self, amount: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ..., fee_account: _Optional[str] = ..., source_account: _Optional[str] = ...) -> None: ...

class BurnInstrumentResponse(_message.Message):
    __slots__ = ("transaction_id",)
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    transaction_id: str
    def __init__(self, transaction_id: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Address(_message.Message):
    __slots__ = ("address_lines", "suburb", "city", "province", "country_code", "postal_code")
    ADDRESS_LINES_FIELD_NUMBER: _ClassVar[int]
    SUBURB_FIELD_NUMBER: _ClassVar[int]
    CITY_FIELD_NUMBER: _ClassVar[int]
    PROVINCE_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_CODE_FIELD_NUMBER: _ClassVar[int]
    POSTAL_CODE_FIELD_NUMBER: _ClassVar[int]
    address_lines: _containers.RepeatedScalarFieldContainer[str]
    suburb: str
    city: str
    province: str
    country_code: str
    postal_code: str
    def __init__(self, address_lines: _Optional[_Iterable[str]] = ..., suburb: _Optional[str] = ..., city: _Optional[str] = ..., province: _Optional[str] = ..., country_code: _Optional[str] = ..., postal_code: _Optional[str] = ...) -> None: ...



import decimal

from .decimal_pb2 import Decimal


def built_in_to_decimal(decimal_value: decimal.Decimal) -> Decimal:
    """
    Converts an instance of the built-in decimal.Decimal type to an instance of the
    financial Decimal protobuf type.

    :param decimal_value: The decimal.Decimal object to convert.
    :return: The converted financial Decimal protobuf object.
    """

    # Contruct and return resultant decimal object
    return Decimal(
        value=str(decimal_value),
    )


def decimal_to_built_in(decimal_value: Decimal) -> decimal.Decimal:
    """
    Converts an instance of the financial Decimal protobuf type to an instance of the
    built-in decimal.Decimal type.

    :param decimal_value: The decimal_pb2.Decimal object to convert.
    :return: The converted decimal.Decimal object.
    """
    return decimal.Decimal( decimal_value.value if decimal_value.value != "" else "0"  )



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class TransactionState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TRANSACTION_STATE_UNSPECIFIED: _ClassVar[TransactionState]
    TRANSACTION_STATE_DRAFT: _ClassVar[TransactionState]
    TRANSACTION_STATE_SIGNING_IN_PROGRESS: _ClassVar[TransactionState]
    TRANSACTION_STATE_PENDING: _ClassVar[TransactionState]
    TRANSACTION_STATE_SUBMISSION_IN_PROGRESS: _ClassVar[TransactionState]
    TRANSACTION_STATE_FAILED: _ClassVar[TransactionState]
    TRANSACTION_STATE_INDETERMINATE: _ClassVar[TransactionState]
    TRANSACTION_STATE_SUCCESSFUL: _ClassVar[TransactionState]
TRANSACTION_STATE_UNSPECIFIED: TransactionState
TRANSACTION_STATE_DRAFT: TransactionState
TRANSACTION_STATE_SIGNING_IN_PROGRESS: TransactionState
TRANSACTION_STATE_PENDING: TransactionState
TRANSACTION_STATE_SUBMISSION_IN_PROGRESS: TransactionState
TRANSACTION_STATE_FAILED: TransactionState
TRANSACTION_STATE_INDETERMINATE: TransactionState
TRANSACTION_STATE_SUCCESSFUL: TransactionState



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/trading/limit_order/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/trading/limit_order/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.trading.limit_order.v1 import limit_order_pb2 as meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.meshtrade/trading/limit_order/v1/service.proto\x12 meshtrade.trading.limit_order.v1\x1a\x32meshtrade/trading/limit_order/v1/limit_order.proto\".\n\x14GetLimitOrderRequest\x12\x16\n\x06number\x18\x01 \x01(\tR\x06number2\x8a\x01\n\x11LimitOrderService\x12u\n\rGetLimitOrder\x12\x36.meshtrade.trading.limit_order.v1.GetLimitOrderRequest\x1a,.meshtrade.trading.limit_order.v1.LimitOrderBAZ?github.com/meshtrade/api/go/trading/limit_order/v1;limitorderv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.trading.limit_order.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z?github.com/meshtrade/api/go/trading/limit_order/v1;limitorderv1'
  _globals['_GETLIMITORDERREQUEST']._serialized_start=136
  _globals['_GETLIMITORDERREQUEST']._serialized_end=182
  _globals['_LIMITORDERSERVICE']._serialized_start=185
  _globals['_LIMITORDERSERVICE']._serialized_end=323
# @@protoc_insertion_point(module_scope)



from buf.validate import validate_pb2 as _validate_pb2
from meshtrade.option.v1 import auth_pb2 as _auth_pb2
from meshtrade.option.v1 import service_type_pb2 as _service_type_pb2
from meshtrade.type.v1 import ledger_pb2 as _ledger_pb2
from meshtrade.wallet.account.v1 import account_pb2 as _account_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateAccountRequest(_message.Message):
    __slots__ = ("label", "ledger", "open")
    LABEL_FIELD_NUMBER: _ClassVar[int]
    LEDGER_FIELD_NUMBER: _ClassVar[int]
    OPEN_FIELD_NUMBER: _ClassVar[int]
    label: str
    ledger: _ledger_pb2.Ledger
    open: bool
    def __init__(self, label: _Optional[str] = ..., ledger: _Optional[_Union[_ledger_pb2.Ledger, str]] = ..., open: bool = ...) -> None: ...

class GetAccountRequest(_message.Message):
    __slots__ = ("number",)
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    number: str
    def __init__(self, number: _Optional[str] = ...) -> None: ...

class ListAccountsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListAccountsResponse(_message.Message):
    __slots__ = ("accounts",)
    ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    accounts: _containers.RepeatedCompositeFieldContainer[_account_pb2.Account]
    def __init__(self, accounts: _Optional[_Iterable[_Union[_account_pb2.Account, _Mapping]]] = ...) -> None: ...

class SearchAccountsRequest(_message.Message):
    __slots__ = ("label",)
    LABEL_FIELD_NUMBER: _ClassVar[int]
    label: str
    def __init__(self, label: _Optional[str] = ...) -> None: ...

class SearchAccountsResponse(_message.Message):
    __slots__ = ("accounts",)
    ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    accounts: _containers.RepeatedCompositeFieldContainer[_account_pb2.Account]
    def __init__(self, accounts: _Optional[_Iterable[_Union[_account_pb2.Account, _Mapping]]] = ...) -> None: ...



from typing import Dict

from .ledger_pb2 import Ledger

_ledger_decimal_places: Dict[Ledger, int] = {
    Ledger.LEDGER_STELLAR: 7,
    Ledger.LEDGER_SA_STOCK_BROKERS: 2,
}

class UnsupportedLedgerError(Exception):
    """Exception raised for unsupported Ledger values."""

    def __init__(self, ledger: Ledger):
        self.financial_business_day_convention = ledger
        message = f"Unsupported Ledger: {ledger}"
        super().__init__(message)


def get_ledger_no_decimal_places(ledger: Ledger) -> int:
    """
    Returns the number of decimal places supported by the given Ledger
    """
    if ledger in _ledger_decimal_places:
        return _ledger_decimal_places[ledger]
    else:
        raise UnsupportedLedgerError(ledger)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/type/v1/amount.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/type/v1/amount.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.type.v1 import decimal_pb2 as meshtrade_dot_type_dot_v1_dot_decimal__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1emeshtrade/type/v1/amount.proto\x12\x11meshtrade.type.v1\x1a\x1fmeshtrade/type/v1/decimal.proto\x1a\x1dmeshtrade/type/v1/token.proto\"j\n\x06\x41mount\x12.\n\x05token\x18\x01 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x05token\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.meshtrade.type.v1.DecimalR\x05valueB,Z*github.com/meshtrade/api/go/type/v1;typev1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.type.v1.amount_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z*github.com/meshtrade/api/go/type/v1;typev1'
  _globals['_AMOUNT']._serialized_start=117
  _globals['_AMOUNT']._serialized_end=223
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/company_representative.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/company_representative.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from meshtrade.compliance.client.v1 import company_representative_role_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_company__representative__role__pb2
from meshtrade.compliance.client.v1 import natural_person_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_natural__person__pb2
from meshtrade.type.v1 import contact_details_pb2 as meshtrade_dot_type_dot_v1_dot_contact__details__pb2
from meshtrade.type.v1 import decimal_pb2 as meshtrade_dot_type_dot_v1_dot_decimal__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;meshtrade/compliance/client/v1/company_representative.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x16google/type/date.proto\x1a@meshtrade/compliance/client/v1/company_representative_role.proto\x1a\x33meshtrade/compliance/client/v1/natural_person.proto\x1a\'meshtrade/type/v1/contact_details.proto\x1a\x1fmeshtrade/type/v1/decimal.proto\"\xcf\x03\n\x15\x43ompanyRepresentative\x12T\n\x0enatural_person\x18\x01 \x01(\x0b\x32-.meshtrade.compliance.client.v1.NaturalPersonR\rnaturalPerson\x12M\n\x04role\x18\x02 \x01(\x0e\x32\x39.meshtrade.compliance.client.v1.CompanyRepresentativeRoleR\x04role\x12\x1a\n\x08position\x18\x03 \x01(\tR\x08position\x12M\n\x14ownership_percentage\x18\x04 \x01(\x0b\x32\x1a.meshtrade.type.v1.DecimalR\x13ownershipPercentage\x12\x63\n\x1cprofessional_contact_details\x18\x05 \x01(\x0b\x32!.meshtrade.type.v1.ContactDetailsR\x1aprofessionalContactDetails\x12\x41\n\x13\x64\x61te_of_appointment\x18\x06 \x01(\x0b\x32\x11.google.type.DateR\x11\x64\x61teOfAppointmentB;Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.company_representative_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1'
  _globals['_COMPANYREPRESENTATIVE']._serialized_start=313
  _globals['_COMPANYREPRESENTATIVE']._serialized_end=776
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/company_representative_role.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/company_representative_role.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@meshtrade/compliance/client/v1/company_representative_role.proto\x12\x1emeshtrade.compliance.client.v1*\xc4\x03\n\x19\x43ompanyRepresentativeRole\x12+\n\'COMPANY_REPRESENTATIVE_ROLE_UNSPECIFIED\x10\x00\x12\x39\n5COMPANY_REPRESENTATIVE_ROLE_ULTIMATE_BENEFICIAL_OWNER\x10\x01\x12+\n\'COMPANY_REPRESENTATIVE_ROLE_SHAREHOLDER\x10\x02\x12/\n+COMPANY_REPRESENTATIVE_ROLE_SOLE_PROPRIETOR\x10\x03\x12\'\n#COMPANY_REPRESENTATIVE_ROLE_PARTNER\x10\x04\x12(\n$COMPANY_REPRESENTATIVE_ROLE_DIRECTOR\x10\x05\x12\'\n#COMPANY_REPRESENTATIVE_ROLE_MANAGER\x10\x06\x12\x34\n0COMPANY_REPRESENTATIVE_ROLE_AUTHORIZED_SIGNATORY\x10\x07\x12/\n+COMPANY_REPRESENTATIVE_ROLE_PRIMARY_CONTACT\x10\x08\x42;Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.company_representative_role_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1'
  _globals['_COMPANYREPRESENTATIVEROLE']._serialized_start=101
  _globals['_COMPANYREPRESENTATIVEROLE']._serialized_end=553
# @@protoc_insertion_point(module_scope)



from google.type import date_pb2 as _date_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Trust(_message.Message):
    __slots__ = ("registered_name", "registration_number", "tax_identifier", "country_of_domicile", "date_of_inception")
    REGISTERED_NAME_FIELD_NUMBER: _ClassVar[int]
    REGISTRATION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    TAX_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_OF_DOMICILE_FIELD_NUMBER: _ClassVar[int]
    DATE_OF_INCEPTION_FIELD_NUMBER: _ClassVar[int]
    registered_name: str
    registration_number: str
    tax_identifier: str
    country_of_domicile: str
    date_of_inception: _date_pb2.Date
    def __init__(self, registered_name: _Optional[str] = ..., registration_number: _Optional[str] = ..., tax_identifier: _Optional[str] = ..., country_of_domicile: _Optional[str] = ..., date_of_inception: _Optional[_Union[_date_pb2.Date, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/issuance_hub/instrument/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/issuance_hub/instrument/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.issuance_hub.instrument.v1 import instrument_pb2 as meshtrade_dot_issuance__hub_dot_instrument_dot_v1_dot_instrument__pb2
from meshtrade.type.v1 import amount_pb2 as meshtrade_dot_type_dot_v1_dot_amount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2meshtrade/issuance_hub/instrument/v1/service.proto\x12$meshtrade.issuance_hub.instrument.v1\x1a\x35meshtrade/issuance_hub/instrument/v1/instrument.proto\x1a\x1emeshtrade/type/v1/amount.proto\"*\n\x14GetInstrumentRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"\x9c\x01\n\x15MintInstrumentRequest\x12\x31\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x06\x61mount\x12\x1f\n\x0b\x66\x65\x65_account\x18\x02 \x01(\tR\nfeeAccount\x12/\n\x13\x64\x65stination_account\x18\x03 \x01(\tR\x12\x64\x65stinationAccount\"?\n\x16MintInstrumentResponse\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\"\x92\x01\n\x15\x42urnInstrumentRequest\x12\x31\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x06\x61mount\x12\x1f\n\x0b\x66\x65\x65_account\x18\x02 \x01(\tR\nfeeAccount\x12%\n\x0esource_account\x18\x03 \x01(\tR\rsourceAccount\"?\n\x16\x42urnInstrumentResponse\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId2\xae\x03\n\x11InstrumentService\x12}\n\rGetInstrument\x12:.meshtrade.issuance_hub.instrument.v1.GetInstrumentRequest\x1a\x30.meshtrade.issuance_hub.instrument.v1.Instrument\x12\x8b\x01\n\x0eMintInstrument\x12;.meshtrade.issuance_hub.instrument.v1.MintInstrumentRequest\x1a<.meshtrade.issuance_hub.instrument.v1.MintInstrumentResponse\x12\x8b\x01\n\x0e\x42urnInstrument\x12;.meshtrade.issuance_hub.instrument.v1.BurnInstrumentRequest\x1a<.meshtrade.issuance_hub.instrument.v1.BurnInstrumentResponseBEZCgithub.com/meshtrade/api/go/issuance_hub/instrument/v1;instrumentv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.issuance_hub.instrument.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/meshtrade/api/go/issuance_hub/instrument/v1;instrumentv1'
  _globals['_GETINSTRUMENTREQUEST']._serialized_start=179
  _globals['_GETINSTRUMENTREQUEST']._serialized_end=221
  _globals['_MINTINSTRUMENTREQUEST']._serialized_start=224
  _globals['_MINTINSTRUMENTREQUEST']._serialized_end=380
  _globals['_MINTINSTRUMENTRESPONSE']._serialized_start=382
  _globals['_MINTINSTRUMENTRESPONSE']._serialized_end=445
  _globals['_BURNINSTRUMENTREQUEST']._serialized_start=448
  _globals['_BURNINSTRUMENTREQUEST']._serialized_end=594
  _globals['_BURNINSTRUMENTRESPONSE']._serialized_start=596
  _globals['_BURNINSTRUMENTRESPONSE']._serialized_end=659
  _globals['_INSTRUMENTSERVICE']._serialized_start=662
  _globals['_INSTRUMENTSERVICE']._serialized_end=1092
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/option/v1/auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/option/v1/auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1emeshtrade/option/v1/auth.proto\x12\x13meshtrade.option.v1\x1a google/protobuf/descriptor.proto\";\n\x08RoleList\x12/\n\x05roles\x18\x01 \x03(\x0e\x32\x19.meshtrade.option.v1.RoleR\x05roles*K\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\x15\n\x11ROLE_WALLET_ADMIN\x10\x01\x12\x16\n\x12ROLE_WALLET_VIEWER\x10\x02:d\n\x0estandard_roles\x12\x1c.google.protobuf.FileOptions\x18\xd3\x86\x03 \x01(\x0b\x32\x1d.meshtrade.option.v1.RoleListR\rstandardRoles:U\n\x05roles\x12\x1e.google.protobuf.MethodOptions\x18\xd5\x86\x03 \x01(\x0b\x32\x1d.meshtrade.option.v1.RoleListR\x05rolesB0Z.github.com/meshtrade/api/go/option/v1;optionv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.option.v1.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/meshtrade/api/go/option/v1;optionv1'
  _globals['_ROLE']._serialized_start=150
  _globals['_ROLE']._serialized_end=225
  _globals['_ROLELIST']._serialized_start=89
  _globals['_ROLELIST']._serialized_end=148
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/wallet/account/v1/account.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/wallet/account/v1/account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)meshtrade/wallet/account/v1/account.proto\x12\x1bmeshtrade.wallet.account.v1\"\x1d\n\x07\x41\x63\x63ount\x12\x12\n\x04name\x18\x01 \x01(\tR\x04nameB9Z7github.com/meshtrade/api/go/wallet/account/v1;accountv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.wallet.account.v1.account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/meshtrade/api/go/wallet/account/v1;accountv1'
  _globals['_ACCOUNT']._serialized_start=74
  _globals['_ACCOUNT']._serialized_end=103
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/type/v1/address.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/type/v1/address.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmeshtrade/type/v1/address.proto\x12\x11meshtrade.type.v1\"\xba\x01\n\x07\x41\x64\x64ress\x12#\n\raddress_lines\x18\x01 \x03(\tR\x0c\x61\x64\x64ressLines\x12\x16\n\x06suburb\x18\x02 \x01(\tR\x06suburb\x12\x12\n\x04\x63ity\x18\x03 \x01(\tR\x04\x63ity\x12\x1a\n\x08province\x18\x04 \x01(\tR\x08province\x12!\n\x0c\x63ountry_code\x18\x05 \x01(\tR\x0b\x63ountryCode\x12\x1f\n\x0bpostal_code\x18\x06 \x01(\tR\npostalCodeB,Z*github.com/meshtrade/api/go/type/v1;typev1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.type.v1.address_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z*github.com/meshtrade/api/go/type/v1;typev1'
  _globals['_ADDRESS']._serialized_start=55
  _globals['_ADDRESS']._serialized_end=241
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/trust.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/trust.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*meshtrade/compliance/client/v1/trust.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x16google/type/date.proto\"\xf7\x01\n\x05Trust\x12\'\n\x0fregistered_name\x18\x01 \x01(\tR\x0eregisteredName\x12/\n\x13registration_number\x18\x02 \x01(\tR\x12registrationNumber\x12%\n\x0etax_identifier\x18\x03 \x01(\tR\rtaxIdentifier\x12.\n\x13\x63ountry_of_domicile\x18\x04 \x01(\tR\x11\x63ountryOfDomicile\x12=\n\x11\x64\x61te_of_inception\x18\x05 \x01(\x0b\x32\x11.google.type.DateR\x0f\x64\x61teOfInceptionB;Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.trust_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1'
  _globals['_TRUST']._serialized_start=103
  _globals['_TRUST']._serialized_end=350
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/source_of_income_and_wealth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/source_of_income_and_wealth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@meshtrade/compliance/client/v1/source_of_income_and_wealth.proto\x12\x1emeshtrade.compliance.client.v1*\x99\t\n\x17SourceOfIncomeAndWealth\x12+\n\'SOURCE_OF_INCOME_AND_WEALTH_UNSPECIFIED\x10\x00\x12*\n&SOURCE_OF_INCOME_AND_WEALTH_ALLOWANCES\x10\x01\x12\'\n#SOURCE_OF_INCOME_AND_WEALTH_BURSARY\x10\x02\x12+\n\'SOURCE_OF_INCOME_AND_WEALTH_COURT_ORDER\x10\x03\x12:\n6SOURCE_OF_INCOME_AND_WEALTH_LOAN_FINANCIAL_INSTITUTION\x10\x04\x12*\n&SOURCE_OF_INCOME_AND_WEALTH_LOAN_OTHER\x10\x05\x12+\n\'SOURCE_OF_INCOME_AND_WEALTH_MAINTENANCE\x10\x06\x12\x34\n0SOURCE_OF_INCOME_AND_WEALTH_MATURING_INVESTMENTS\x10\x07\x12\'\n#SOURCE_OF_INCOME_AND_WEALTH_PENSION\x10\x08\x12-\n)SOURCE_OF_INCOME_AND_WEALTH_RENTAL_INCOME\x10\t\x12/\n+SOURCE_OF_INCOME_AND_WEALTH_COMPANY_PROFITS\x10\n\x12,\n(SOURCE_OF_INCOME_AND_WEALTH_COMPANY_SALE\x10\x0b\x12/\n+SOURCE_OF_INCOME_AND_WEALTH_DECEASED_ESTATE\x10\x0c\x12\x32\n.SOURCE_OF_INCOME_AND_WEALTH_DIVORCE_SETTLEMENT\x10\r\x12\x30\n,SOURCE_OF_INCOME_AND_WEALTH_GIFT_OR_DONATION\x10\x0e\x12\x36\n2SOURCE_OF_INCOME_AND_WEALTH_INCOME_FROM_EMPLOYMENT\x10\x0f\x12?\n;SOURCE_OF_INCOME_AND_WEALTH_INCOME_FROM_PREVIOUS_EMPLOYMENT\x10\x10\x12+\n\'SOURCE_OF_INCOME_AND_WEALTH_INHERITANCE\x10\x11\x12<\n8SOURCE_OF_INCOME_AND_WEALTH_LOTTERY_WINNINGS_OR_GAMBLING\x10\x12\x12-\n)SOURCE_OF_INCOME_AND_WEALTH_SALE_OF_ASSET\x10\x13\x12.\n*SOURCE_OF_INCOME_AND_WEALTH_SALE_OF_SHARES\x10\x14\x12>\n:SOURCE_OF_INCOME_AND_WEALTH_SAVINGS_INVESTMENT_OR_DIVIDEND\x10\x15\x12\x33\n/SOURCE_OF_INCOME_AND_WEALTH_TRUST_DISTRIBUTIONS\x10\x16\x42;Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.source_of_income_and_wealth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1'
  _globals['_SOURCEOFINCOMEANDWEALTH']._serialized_start=101
  _globals['_SOURCEOFINCOMEANDWEALTH']._serialized_end=1278
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ServiceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SERVICE_TYPE_UNSPECIFIED: _ClassVar[ServiceType]
    SERVICE_TYPE_READ: _ClassVar[ServiceType]
    SERVICE_TYPE_WRITE: _ClassVar[ServiceType]
SERVICE_TYPE_UNSPECIFIED: ServiceType
SERVICE_TYPE_READ: ServiceType
SERVICE_TYPE_WRITE: ServiceType
SERVICE_TYPE_FIELD_NUMBER: _ClassVar[int]
service_type: _descriptor.FieldDescriptor



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DirectOrder(_message.Message):
    __slots__ = ("number",)
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    number: str
    def __init__(self, number: _Optional[str] = ...) -> None: ...
